@@ -5,6 +5,7 @@ from typing import Text
 
 import click
 from rich.console import Console
+from rich.prompt import Prompt
 from rich.table import Table
 
 from neuralspace import VERSION
@@ -79,20 +80,24 @@ def install_app(name: Text, log_level: Text):
     "-e",
     "--email",
     type=click.STRING,
-    required=True,
+    required=False,
     help="Your NeuralSpace email id",
 )
 @click.option(
     "-p",
     "--password",
     type=click.STRING,
-    required=True,
+    required=False,
     help="Your NeuralSpace account password",
 )
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
 )
 def login(email: Text, password: Text, log_level: Text):
+    if not email:
+        email = Prompt.ask("Enter your email")
+    if not password:
+        password = Prompt.ask("Enter your password", password=True)
     setup_logger(log_level=log_level)
     print_logo()
     loop = asyncio.new_event_loop()
