@@ -6,7 +6,18 @@ from typing import Text
 from rich.console import Console
 
 from neuralspace.apis import get_async_http_session
-from neuralspace.constants import AUTHORIZATION, COMMON_HEADERS, DATA, ENTITIES
+from neuralspace.constants import (
+    AUTHORIZATION,
+    COMMON_HEADERS,
+    CROSS,
+    DATA,
+    ENTITIES,
+    GREEN_TICK,
+    INFO,
+    RED_END,
+    RED_START,
+    ROCKET,
+)
 from neuralspace.ner.constants import NER_APP_URL
 from neuralspace.utils import (
     get_auth_token,
@@ -24,7 +35,7 @@ async def get_ner_response(text: Text, language: Text):
     HEADERS[AUTHORIZATION] = get_auth_token()
     payload = {"text": text, "language": language}
     console.print(
-        ">[deep_sky_blue2] INFO [/deep_sky_blue2] Sending 🚀 Request to the server..."
+        f">[deep_sky_blue2] INFO [/deep_sky_blue2] Sending {ROCKET}Request to the server..."
     )
     async with get_async_http_session().post(
         url=f"{neuralspace_url()}/{NER_APP_URL}",
@@ -34,12 +45,12 @@ async def get_ner_response(text: Text, language: Text):
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
             console.print(
-                "> [deep_sky_blue2]INFO [/deep_sky_blue2] [green]✅ SUCCESS:[/green] Response received"
-            )
-            console.print(
-                "> [deep_sky_blue2]INFO [/deep_sky_blue2] Parsing the information and creating a table"
+                f"> {INFO} [green]{GREEN_TICK} SUCCESS:[/green] Response received"
             )
+            console.print(f"> {INFO} Parsing the information and creating a table")
             print_ner_response(json_response[DATA][ENTITIES], text)
         else:
-            logger.error("❌ Failed to get NER response")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            logger.error(f"{CROSS} Failed to get NER response")
+            logger.error(
+                f"Platform response: {RED_START}{json_response['message']}{RED_END}"
+            )
