@@ -12,10 +12,7 @@ from rich.console import Console
 
 from neuralspace.apis import get_async_http_session
 from neuralspace.constants import (
-    BAG,
     ERROR,
-    GREEN_TICK,
-    INFO,
     NAME_GENERATOR_CONFIG,
     NER_TYPES,
     ORANGE3_END,
@@ -40,6 +37,7 @@ from neuralspace.nlu.apis import (
     wait_till_training_completes,
 )
 from neuralspace.nlu.constants import SUPPORTED_LANGUAGES, TRAINING_PROGRESS
+from neuralspace.nlu.utils import print_converted_data_inference
 from neuralspace.utils import get_entity_list, print_logo, setup_logger
 
 console = Console()
@@ -53,7 +51,7 @@ class MappingClass(click.ParamType):
         value: typing.Any,
         param: typing.Optional["Parameter"],
         ctx: typing.Optional["Context"],
-    ) -> typing.Any:
+    ) -> typing.Union[typing.Dict[Text, Text], bool]:
         entity_mapping = value.split(",")
         total_entity_mapping = []
         for entities in entity_mapping:
@@ -93,9 +91,9 @@ def nlu_get_languages(log_level: Text):
 @click.option(
     "-F",
     "--from-platform",
-    type=click.Choice(["dialogflow", "rasa"], case_sensitive=False),
+    type=click.Choice(["dialogflow", "rasa", "csv"], case_sensitive=False),
     required=True,
-    help="From where to convert data from [dialogflow, rasa]",
+    help="From where to convert data from [dialogflow, rasa, csv]",
 )
 @click.option(
     "-at",
@@ -138,14 +136,29 @@ def nlu_get_languages(log_level: Text):
     required=True,
     help="Name of the folder in which the converted dataset files want to be stored",
 )
+@click.option(
+    "-ime",
+    "--ignore-missing-examples",
+    is_flag=True,
+    default=False,
+    help="Will ignore if there is any missing examples in your data(works with csv files only)",
+)
+@click.option(
+    "-iswp",
+    "--ignore-swapped-columns",
+    is_flag=True,
+    default=False,
+    help="Will ignore if there is swapped columns in your nlu examples data(works with csv files only)",
+)
 def converter(
     from_platform: Text,
     auto_tag_entities: bool,
     language: Text,
-    entity_mapping: List,
-    input_path: Text,
+    entity_mapping: typing.Dict[Text, Text],
+    input_path: List[Text],
     data_type: Text,
     output_path: Text,
+    ignore_missing_examples: bool,
 ):
     if entity_mapping is not False:
         if from_platform == "rasa":
@@ -157,17 +170,11 @@ def converter(
                 auto_tag_entities=auto_tag_entities,
             )
             converter.convert(
-                input_path=input_path,
+                input_path=[Path(path) for path in input_path],
                 output_directory=Path(output_path),
                 dataset_type=DatasetTypes(data_type).value,
             )
-            console.print(
-                f"> {GREEN_TICK} SUCCESS Your {from_platform} dataset is now converted to Neuralspace-platform data"
-            )
-            console.print(
-                f"> {INFO} Converted dataset is {BAG} stored in: {output_path}"
-            )
-        else:
+        elif from_platform == "dialogflow":
             from neuralspace.nlu.converters.dialogflowconverter import (
                 DialogflowConverter,
             )
@@ -178,11 +185,25 @@ def converter(
                 auto_tag_entities=auto_tag_entities,
             )
             converter.convert(
-                input_path=input_path,
+                input_path=[Path(path) for path in input_path],
                 output_directory=Path(output_path),
                 dataset_type=DatasetTypes(data_type).value,
             )
+        else:
+            from neuralspace.nlu.converters.csvconverter import CsvConverter
 
+            converter = CsvConverter(
+                language=language,
+                entity_mapping=entity_mapping,
+                auto_tag_entities=auto_tag_entities,
+                ignore_missing_examples=ignore_missing_examples,
+            )
+            converter.convert(
+                input_path=Path(input_path[0]),
+                output_directory=Path(output_path),
+                dataset_type=DatasetTypes(data_type).value,
+            )
+        print_converted_data_inference(from_platform, output_path, converter)
     else:
         console.print(
             f"{ERROR} There is some error in the entity mapping you have given"
