@@ -1,21 +1,28 @@
 import json
+import time as t
 from copy import copy
+from pathlib import Path
 from typing import Any, Dict, List, Text, Tuple
 
 import numpy
 import requests
 from rich.console import Console
+from rich.table import Table
 
 from neuralspace.constants import (
     AUTHORIZATION,
+    BAG,
     COMMON_HEADERS,
     COUNT,
+    CROSS,
     DATA,
     ENTITIES,
     ENTITY,
     ENTITY_TYPE,
     EXAMPLES,
     FILTER,
+    GREEN_TICK,
+    INFO,
     LANGUAGE,
     LIST_ENTITY_URL,
     LOOKUP,
@@ -160,3 +167,46 @@ def remove_entity_duplicates(
     for entity in entities:
         entity[EXAMPLES] = sorted(list(set(entity[EXAMPLES])), key=str.casefold)
     return entities
+
+
+def print_converted_data_inference(from_platform: Text, output_path: Path, converter):
+    console.print(
+        f"> {GREEN_TICK} SUCCESS Your {from_platform} dataset is now converted to Neuralspace-platform data"
+    )
+    console.print(f"> {INFO} Converted dataset is {BAG} stored in: {output_path}")
+    table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
+    table.add_column("Contents")
+    table.add_column("Total")
+    table.add_row(
+        "Number of examples before removing duplicates",
+        str(converter.number_of_nlu_examples_before_duplicate_check),
+    )
+    table.add_row(
+        "Number of examples after removing the duplicates",
+        str(converter.number_of_nlu_examples_after_duplicate_check),
+    )
+    table.add_row("Number of intent present", str(converter.number_of_unique_intent()))
+    console.print(table)
+    console.print(
+        "Number of duplicates found: ",
+        str(
+            converter.number_of_nlu_examples_before_duplicate_check
+            - converter.number_of_nlu_examples_after_duplicate_check
+        ),
+    )
+    console.print("\nChecking Files... \n")
+    console.print("> Lookups", end=" ")
+    t.sleep(1)
+    console.print(f"{GREEN_TICK} ") if converter.lookup_data else console.print(
+        f"{CROSS}"
+    )
+    console.print("> Synonyms", end=" ")
+    t.sleep(1)
+    console.print(f"{GREEN_TICK} ") if converter.synonym_data else console.print(
+        f"{CROSS}"
+    )
+    console.print("> Regex", end=" ")
+    t.sleep(1)
+    console.print(f"{GREEN_TICK} ") if converter.regex_data else console.print(
+        f"{CROSS}"
+    )
