@@ -17,6 +17,7 @@ from neuralspace.constants import (
     BOLD_START,
     BOOK,
     COMMON_HEADERS,
+    COUNT,
     CROSS,
     DARK_ORANGE_END,
     DARK_ORANGE_START,
@@ -182,6 +183,43 @@ def add_apps_to_table(table: Table) -> Table:
         "addresses, account numbers to very domain specific terms like names of chemicals, medicines, etc. "
         "Essentially any valuable information that can be extracted from text.",
     )
+    table.add_row(
+        f"{BOLD_START}translation{BOLD_END}",
+        "neuralspace [bold red]translation[/bold red]",
+        "Whether we are talking about subtitles, government documents or question papers for exams, all of them "
+        "need to be translated into multiple languages. Manually translating documents at such a scale is not "
+        "only expensive but also an extremely time consuming process. With the help of Neural Machine "
+        "Translation (NMT) you can drastically reduce the amount of time it takes for manual translation "
+        "of documents. Our translation models are all state-of-the-art Artificial Neural Networks which can "
+        "translate text in over 100 languages. ",
+    )
+    table.add_row(
+        f"{BOLD_START}transliteration{BOLD_END}",
+        "neuralspace [bold red]transliteration[/bold red]",
+        "For languages that don't use the latin script, e.g., Arabic, Hindi, Punjabi, Sinhala and many "
+        "other spoken around the world, typing can be challenging as keyboards/keypads mostly default to "
+        "latin characters. That makes creating content in vernacular languages difficult. With "
+        "transliteration you can create content in these languages using your latin keypad. "
+        "For instance, you type a word on the latin keypad the way you would pronounce it in Punjabi, "
+        "and using transliteration you can convert that into Punjabi. It transforms a word from one "
+        "alphabet to the other phonetically. ",
+    )
+    table.add_row(
+        f"{BOLD_START}augmentation{BOLD_END}",
+        "neuralspace [bold red]augmentation[/bold red]",
+        "Any language processing task requires data, and we all wish we could generate data "
+        "magically. That was exactly the idea behind building NeuralAug. Given a sentence NeuralAug "
+        "can generate up to ten sentences keeping the intent of the original sentence intact. It "
+        "can help in creating datasets faster and make language processing models more robust. ",
+    )
+    table.add_row(
+        f"{BOLD_START}language-detection{BOLD_END}",
+        "neuralspace [bold red]language-detection[/bold red]",
+        "Dealing with different languages poses a fundamental problem of first detecting what language "
+        "you are looking at. Language-detection service will help you to detect the language based on "
+        "your input text with given confidence score. Use it with other APIs like transliteration "
+        "or translation and make your NLP application cater to any language you want.",
+    )
     return table
 
 
@@ -256,6 +294,74 @@ def print_ner_response(list_of_entities: List[Dict[Text, Text]], original_text:
         console.print(table)
 
 
+def print_translation_response(
+    text: Text, src_language: Text, tgt_language: Text, translated_text: Text
+):
+    table = Table(show_header=True, header_style="orange3")
+    table.add_column("Text", style="sandy_brown")
+    table.add_column("Src Language", style="green")
+    table.add_column("Tgt Language", style="green")
+    table.add_column("Translated Text", style="green")
+
+    table.add_row(text, src_language, tgt_language, translated_text)
+    console.print(table)
+
+
+def print_transliteration_response(
+    text: Text, src_language: Text, tgt_language: Text, suggestions: Text
+):
+    table = Table(show_header=True, header_style="orange3")
+    table.add_column("Text", style="sandy_brown")
+    table.add_column("Src Language", style="green")
+    table.add_column("Tgt Language", style="green")
+    table.add_column("Transliterated Suggestions", style="green")
+
+    original_text_shown = False
+
+    for suggestion in suggestions:
+        if original_text_shown is False:
+            table.add_row(text, src_language, tgt_language, suggestion)
+            original_text_shown = True
+        else:
+            table.add_row("", "", "", suggestion)
+    console.print(table)
+
+
+def print_language_detection_response(text: Text, detected_languages: List[Dict]):
+    table = Table(show_header=True, header_style="orange3")
+    table.add_column("Text", style="sandy_brown")
+    table.add_column("Detected Language", style="green")
+    table.add_column("Confidence Score", style="green")
+    original_text_shown = False
+
+    for language in detected_languages:
+        if original_text_shown is False:
+            table.add_row(
+                text, language["language"], str(round(float(language["confidence"]), 2))
+            )
+            original_text_shown = True
+        else:
+            table.add_row(
+                "", language["language"], str(round(float(language["confidence"]), 2))
+            )
+    console.print(table)
+
+
+def print_augmentation_response(text: Text, augmentation_suggestions: List):
+    table = Table(show_header=True, header_style="orange3")
+    table.add_column("Text", style="sandy_brown")
+    table.add_column("Suggestions", style="green")
+    original_text_shown = False
+
+    for augmentation in augmentation_suggestions:
+        if original_text_shown is False:
+            table.add_row(text, augmentation)
+            original_text_shown = True
+        else:
+            table.add_row("", augmentation)
+    console.print(table)
+
+
 def print_get_entity(response_to_print):
     table = Table(show_header=True, header_style="orange3")
     table.add_column("idx", style="sandy_brown")
@@ -286,7 +392,8 @@ async def get_entity_list(
         if is_success_status(response.status):
             console.print(
                 f"> {INFO} {BOOK} Entities available for Page "
-                f"{ORANGE3_START}{page_number}{ORANGE3_END} with Page Size: {ORANGE3_START}{page_size}{ORANGE3_END}"
+                f"{ORANGE3_START}{page_number}{ORANGE3_END} of {json_response[DATA][COUNT]} "
+                f"with Page Size: {ORANGE3_START}{page_size}{ORANGE3_END}"
             )
             print_get_entity(json_response)
         else:
